% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/diagnose.R
\name{plot_outlier.target_df}
\alias{plot_outlier.target_df}
\title{Plot outlier information of target_df}
\usage{
\method{plot_outlier}{target_df}(.data, ..., typographic = TRUE)
}
\arguments{
\item{.data}{a target_df. reference \code{\link{target_by}}.}

\item{...}{one or more unquoted expressions separated by commas.
You can treat variable names like they are positions.
Positive values select variables; negative values to drop variables.
If the first expression is negative, plot_outlier() will automatically start
with all variables.
These arguments are automatically quoted and evaluated in a context
where column names represent column positions.
They support unquoting and splicing.}

\item{typographic}{logical. Whether to apply focuses on typographic elements to ggplot2 visualization. 
The default is TRUE. if TRUE provides a base theme that focuses on typographic elements using hrbrthemes package.}
}
\description{
The plot_outlier() visualize outlier information
for diagnosing the quality of the numerical data with target_df class.
}
\details{
The scope of the diagnosis is the provide a outlier information.
Since the plot is drawn for each variable, if you specify more than
one variable in the ... argument, the specified number of plots are drawn.
}
\section{Outlier diagnostic information}{

The plot derived from the numerical data diagnosis is as follows.

\itemize{
\item With outliers box plot by target variable
\item Without outliers box plot by target variable
\item With outliers density plot by target variable
\item Without outliers density plot by target variable
}
}

\examples{
# Generate data for the example
carseats <- ISLR::Carseats
carseats[sample(seq(NROW(carseats)), 20), "Income"] <- NA
carseats[sample(seq(NROW(carseats)), 5), "Urban"] <- NA

# the target variable is a categorical variable
categ <- target_by(carseats, US)

plot_outlier(categ, Price)
plot_outlier(categ, Price, typographic = FALSE)

# using dplyr
library(dplyr)
carseats \%>\% 
  target_by(US) \%>\% 
  plot_outlier(Price, CompPrice)

# Using DBMS tables ----------------------------------
# connect DBMS
con_sqlite <- DBI::dbConnect(RSQLite::SQLite(), ":memory:")

# copy carseats to the DBMS with a table named TB_CARSEATS
copy_to(con_sqlite, carseats, name = "TB_CARSEATS", overwrite = TRUE)

# If the target variable is a categorical variable
categ <- target_by(con_sqlite \%>\% tbl("TB_CARSEATS") , US)

plot_outlier(categ, Price)

}
\seealso{
\code{\link{plot_outlier.data.frame}}.
}
